@@ -12,7 +12,7 @@ package Map::Tube::KoelnBonn;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.07';
 
 =encoding utf8
 
@@ -70,12 +70,12 @@ the constructor will die.
 
 =head1 AUTHOR
 
-Gisbert W. Selke, TapirSoft Selke & Selke GbR.
+Gisbert W. Selke, TapirSoft Selke & Selke GbR <gws@cpan.org>
 
 =head1 COPYRIGHT AND LICENCE
 
 The data for the XML file were mainly taken from the appropriate OpenStreetMap
-maps. They are CC BY-SA 2.0. Some modifications were made based on personal
+maps. They are CC BY-SA 2.0, with some modifications made based on personal
 knowledge, in particular in order to disambiguate station names. The module
 itself is free software; you may redistribute and/or modify it under the
 same terms as Perl itself.
